#  *
#  *                       cloudFPGA
#  *     Copyright IBM Research, All Rights Reserved
#  *    =============================================
#  *     Created: Feb. 2021
#  *     Authors: DID
#  *
#  *     Description:
#  *      A initialization file for the trieres lib.
#  *
#  *    License:
#  *     Apache Version 2.0

from .trieres import *

